@@ -122,13 +122,13 @@ calcular.indicadores<-function(i.current,
   pos.likehood.ratio[is.nan(pos.likehood.ratio)]<-NA
   neg.likehood.ratio<-(1-sensibilidad)/especificidad
   neg.likehood.ratio[is.nan(neg.likehood.ratio)]<-NA
-
   percent.agreement<-(true.pos+true.neg)/(true.pos+true.neg+false.pos+false.neg)
   percent.agreement[is.nan(percent.agreement)]<-NA
-
   #Matthews correlation coefficient
   mcc<-(true.pos*true.neg-false.pos*false.neg)/sqrt((true.pos+false.pos)*(true.pos+false.neg)*(true.neg+false.pos)*(true.neg+false.neg))
   mcc[is.nan(mcc)]<-NA
+  # Youden's Index
+  youden<-sensibilidad+especificidad-1
 
   if (true.pos.t+false.neg.t>0) sensibilidad.t<-true.pos.t/(true.pos.t+false.neg.t) else sensibilidad.t<-NA
   if (true.neg.t+false.pos.t>0) especificidad.t<-true.neg.t/(true.neg.t+false.pos.t) else especificidad.t<-NA
@@ -139,27 +139,27 @@ calcular.indicadores<-function(i.current,
   neg.likehood.ratio.t<-NA
   if (!is.na(especificidad.t)) if (especificidad.t>0) neg.likehood.ratio.t<-(1-sensibilidad.t)/especificidad.t else neg.likehood.ratio.t<-NA
   if (true.pos.t+true.neg.t+false.pos.t+false.neg.t>0) percent.agreement.t<-(true.pos.t+true.neg.t)/(true.pos.t+true.neg.t+false.pos.t+false.neg.t) else percent.agreement.t<-NA
-
   if ((true.pos.t+false.pos.t)>0 & (true.pos.t+false.neg.t)>0 & (true.neg.t+false.pos.t)>0 & (true.neg.t+false.neg.t)>0) mcc.t<-(true.pos.t*true.neg.t-false.pos.t*false.neg.t)/(sqrt(true.pos.t+false.pos.t)*sqrt(true.pos.t+false.neg.t)*sqrt(true.neg.t+false.pos.t)*sqrt(true.neg.t+false.neg.t)) else mcc.t<-NA
+  youden.t<-sensibilidad.t+especificidad.t-1
 
   semanas.not.na<-sum(!is.na(i.current))
 
   indicadores.t<-as.matrix(c(semanas,semanas.not.na,true.pos.t,false.pos.t,true.neg.t,
                              false.neg.t,sensibilidad.t,especificidad.t,ppv.t,npv.t,
                              pos.likehood.ratio.t,neg.likehood.ratio.t,percent.agreement.t,
-                             mcc.t))
+                             mcc.t,youden.t))
   rownames(indicadores.t)<-c("Weeks","Non-missing weeks","True positives","False positives",
                              "True negatives","False negatives","Sensitivity","Specificity",
                              "Positive predictive value","Negative predictive value",
                              "Positive likehood ratio","Negative likehood ratio",
-                             "Percent agreement","Matthews correlation coefficient")
+                             "Percent agreement","Matthews correlation coefficient", "Youdens Index")
   colnames(indicadores.t)<-"values"
 
   indicadores<-data.frame(parametro=i.valores.parametro.deteccion,semanas=semanas,semanas.not.na=semanas.not.na,
                           true.pos=true.pos,false.pos=false.pos,true.neg=true.neg,false.neg=false.neg,
                           sensibilidad=sensibilidad,especificidad=especificidad,ppv=ppv,npv=npv,
                           pos.likehood.ratio=pos.likehood.ratio,neg.likehood.ratio=neg.likehood.ratio,
-                          percent.agreement=percent.agreement,mcc=mcc)
+                          percent.agreement=percent.agreement,mcc=mcc,youden=youden)
 
   if (i.graph){
 
