@@ -1,5 +1,7 @@
-calcular.optimo.original <-
-function(i.curva.map,i.hsuav){
+#' calculates optimum: original method: second derivative + axis change
+#'
+#' @keywords internal
+calcular.optimo.original<-function(i.curva.map,i.hsuav){
   x<-i.curva.map[,1]
   y<-i.curva.map[,2]
   y.d<-diff(y)
@@ -8,8 +10,8 @@ function(i.curva.map,i.hsuav){
   y.s<-suavizado(y.d,0.6)
   x.n<-normalizar(x.d)
   y.n<-normalizar(y.s)
-	u<-(x.n-y.n)/sqrt(2)
-	v<-sqrt(x.n^2+y.n^2-u^2)
+  u<-(x.n-y.n)/sqrt(2)
+  v<-sqrt(x.n^2+y.n^2-u^2)
   optimo<-which.min(v)
   resultados<-i.curva.map[x==optimo,]
   return(resultados)
